summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 2854b03)
raw | patch | inline | side by side (parent: 2854b03)
author | Sebastian Harl <sh@tokkee.org> | |
Fri, 17 Oct 2014 07:10:03 +0000 (09:10 +0200) | ||
committer | Sebastian Harl <sh@tokkee.org> | |
Fri, 17 Oct 2014 07:10:03 +0000 (09:10 +0200) |
That's more specific.
src/frontend/grammar.y | patch | blob | history | |
src/frontend/parser.c | patch | blob | history | |
src/include/frontend/proto.h | patch | blob | history |
diff --git a/src/frontend/grammar.y b/src/frontend/grammar.y
index 0f01bd33e8a12ba517f4f062315c25a2444602d5..ef479efc336ba30e90182ae72557c0892091fc07 100644 (file)
--- a/src/frontend/grammar.y
+++ b/src/frontend/grammar.y
$$ = SDB_CONN_NODE(sdb_object_create_dT(/* name = */ NULL,
conn_matcher_t, conn_matcher_destroy));
- $$->cmd = CONNECTION_EXPR;
+ $$->cmd = CONNECTION_MATCHER;
CONN_MATCHER($$)->matcher = $1;
}
;
diff --git a/src/frontend/parser.c b/src/frontend/parser.c
index 0e0534e4af3c9c0be6bb93c5ed1dfda319cf75b1..3184ffc23fb355c3ec5e652f7276292ebac5229c 100644 (file)
--- a/src/frontend/parser.c
+++ b/src/frontend/parser.c
if (! node)
return NULL;
- if (node->cmd == CONNECTION_EXPR)
+ if (node->cmd == CONNECTION_MATCHER)
m = CONN_MATCHER(node)->matcher;
else
m = NULL;
index 5e3019cf0ba4e6fad0d410f663108fa51018b7ca..0577550b57f25c8814f7fb399e69b4bd623180b5 100644 (file)
*/
/*
* CONNECTION_EXPR:
* A parsed expression. Only used internally.
*/
- CONNECTION_EXPR = 100,
+ CONNECTION_MATCHER = 100,
} sdb_conn_state_t;
#ifdef __cplusplus
@@
*/
/*
- * CONNECTION_EXPR:
- * A parsed expression. Only used internally.
+ * CONNECTION_MATCHER:
+ * A parsed matcher. Only used internally.
*/